@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for Quintus Prolog 3.3~3.5
-%  Last updated on May 13, 2015
+%  Last updated on September 30, 2015
 %
 %  This file is part of Logtalk <http://logtalk.org/>  
 %  Copyright 1998-2015 Paulo Moura <pmoura@logtalk.org>
@@ -636,9 +636,9 @@ call(F, A1, A2, A3, A4, A5, A6) :-
 		Extension = ''
 	).
 
-% the following auxiliary predicate was written by Per Mildner and 
-% is used here (renamed just to avoid conflicts) with permission
 
+% the following auxiliary predicate is simplified version of code
+% written by Per Mildner and is used here with permission
 '$lgt_strrch'(Xs, G, Ys) :-
 	Xs = [X| Xs1],
 	(	X == G ->
@@ -646,16 +646,10 @@ call(F, A1, A2, A3, A4, A5, A6) :-
 	;	'$lgt_strrch'(Xs1, G, Ys)
 	).
 
-'$lgt_strrch1'(Xs, _G, _Prev, _Ys) :-
-	var(Xs),
-	!,
-	fail.
-'$lgt_strrch1'([], _G, Prev, Ys) :-
-	Ys = Prev.
-'$lgt_strrch1'(Xs, G, Prev, Ys) :-
-	Xs = [X| Xs1],
+'$lgt_strrch1'([], _G, Ys, Ys).
+'$lgt_strrch1'([X| Xs1], G, Prev, Ys) :-
 	(	X == G ->
-		'$lgt_strrch1'(Xs1, G, Xs, Ys)
+		'$lgt_strrch1'(Xs1, G, [X| Xs1], Ys)
 	;	'$lgt_strrch1'(Xs1, G, Prev, Ys)
 	).
 
